import os

from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'README.md')) as f:
    README = f.read()

requires = []

test_require = [
    'pytest >= 5.0.1',
    'pytest-cov >= 2.7.1',
    'codecov >= 2.0.15',
]

setup(
    name='openpivtlib',
    version='1.1.1',
    description='A library containing common elements to openpivt and PIVT apps built on top of openpivt',
    long_description=README,
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python',
        'Intended Audience :: Developers',
    ],
    author='Eric Frechette',
    author_email='eric@softwarefactorylabs.com',
    # url='',
    # keywords='',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    extras_require={
        'test': test_require,
    },
    install_requires=requires,
    python_requires='>= 3.7',
)



import logging
from typing import Optional, Iterable
from . import util


class Plugin:
    def __init__(self, pipeline: str, job_id: int, args: Optional[dict] = None, data_key: Optional[str] = None):
        self.pipeline = pipeline
        self.job_id = job_id
        self.args = args if args is not None else {}
        self.data_key = data_key

        self.logger = PluginLoggerAdapter(util.get_class_logger(self), self.pipeline, self.job_id)

    def execute(self, data: Optional[dict] = None):
        raise NotImplementedError


class Trigger:
    def __init__(self, pipeline: str):
        self.pipeline = pipeline
        self.logger = TriggerLoggerAdapter(util.get_class_logger(self), self.pipeline)

    def run(self):
        raise NotImplementedError


class PluginLoggerAdapter(logging.LoggerAdapter):
    def __init__(self, logger: logging.Logger, pipeline: str, job_id: int):
        super().__init__(logger, {})
        self.pipeline = pipeline
        self.job_id = job_id

    def process(self, msg, kwargs):
        return f'[{self.pipeline}:{self.job_id}] {msg}', kwargs


class TriggerLoggerAdapter(logging.LoggerAdapter):
    def __init__(self, logger: logging.Logger, pipeline: str):
        super().__init__(logger, {})
        self.pipeline = pipeline

    def process(self, msg, kwargs):
        return f'[{self.pipeline}] {msg}', kwargs
